.. _input:

Input
=======

From any input
---------------

.. automodule:: tabledataextractor.input.from_any
    :members:


From .csv file
---------------

.. automodule:: tabledataextractor.input.from_csv
    :members:


From .html file
----------------

.. automodule:: tabledataextractor.input.from_html
    :members:


From Python List
-----------------

.. automodule:: tabledataextractor.input.from_list
    :members:


